==> everycomp-1.20-2.9.8-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/lieonlion/MoreCraftingTablesModule.java <==
package net.mehvahdjukaar.every_compat.modules.lieonlion;

import io.github.lieonlion.lolmct.block.MoreCraftingTableBlock;
import net.mehvahdjukaar.every_compat.EveryCompat;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.moonlight.api.platform.PlatHelper;
import net.mehvahdjukaar.moonlight.api.set.wood.VanillaWoodTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.minecraft.class_1761;
import net.minecraft.class_2248;
import net.minecraft.class_2960;
import net.minecraft.class_3481;
import net.minecraft.class_5321;
import net.minecraft.class_7706;
import net.minecraft.class_7924;

// SUPPORT: v1.2.7+
// NOTE: More Crafting Table is developed by LieOnLion and has both FORGE & FABRIC
public class MoreCraftingTablesModule extends SimpleModule {

    public final SimpleEntrySet<WoodType, class_2248> craftingTable;

    public MoreCraftingTablesModule(String modId) {
        super(modId, "lolmct");
        class_5321<class_1761> tab = class_7706.field_40197;

        String namespace = (PlatHelper.getPlatform().isForge()) ? "forge" : "c";

        craftingTable = SimpleEntrySet.builder(WoodType.class, "crafting_table",
                        getModBlock("spruce_crafting_table"),
                        () -> VanillaWoodTypes.SPRUCE,
                        w -> new MoreCraftingTableBlock(w.planks.method_26403()))
                //TEXTURE: texture is oak_craftng_table's texture
                .addTextureM(EveryCompat.res("block/spruce_crafting_table_front"), EveryCompat.res("block/lolmct/spruce_crafting_table_front_m"))
                .addTextureM(EveryCompat.res("block/spruce_crafting_table_side"), EveryCompat.res("block/lolmct/spruce_crafting_table_side_m"))
                .addTextureM(EveryCompat.res("block/spruce_crafting_table_top"), EveryCompat.res("block/lolmct/spruce_crafting_table_top_m"))
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(new class_2960(namespace,"workbench"), class_7924.field_41254)
                .addTag(new class_2960("lieonstudio:crafting_tables"), class_7924.field_41254)
                .addTag(new class_2960("lieonstudio:crafting_tables"), class_7924.field_41197)
                .addTag(new class_2960(namespace,"workbench"), class_7924.field_41197)
                .addTag(new class_2960("quad:fuel/wood"), class_7924.field_41197)
                .setTabKey(tab)
                .defaultRecipe()
                .build();
        this.addEntry(craftingTable);
    }
}

==> everycomp-1.21-2.11.9-fabric-sources.jar: net/mehvahdjukaar/every_compat/modules/lieonlion/MoreCraftingTablesModule.java <==
package net.mehvahdjukaar.every_compat.modules.lieonlion;

import io.github.lieonlion.lolmct.block.MoreCraftingTableBlock;
import net.mehvahdjukaar.every_compat.EveryCompat;
import net.mehvahdjukaar.every_compat.api.SimpleEntrySet;
import net.mehvahdjukaar.every_compat.api.SimpleModule;
import net.mehvahdjukaar.every_compat.common_classes.TagUtility;
import net.mehvahdjukaar.moonlight.api.set.wood.VanillaWoodTypes;
import net.mehvahdjukaar.moonlight.api.set.wood.WoodType;
import net.minecraft.class_1761;
import net.minecraft.class_2248;
import net.minecraft.class_2960;
import net.minecraft.class_3481;
import net.minecraft.class_5321;
import net.minecraft.class_7706;
import net.minecraft.class_7924;

//SUPPORT: FABRIC-v1.2.8+ | NEOFORGE-v1.2.9+
public class MoreCraftingTablesModule extends SimpleModule {

    public final SimpleEntrySet<WoodType, class_2248> craftingTable;

    public MoreCraftingTablesModule(String modId) {
        super(modId, "lolmct", EveryCompat.MOD_ID);
        class_5321<class_1761> tab = class_7706.field_40197;

        craftingTable = SimpleEntrySet.builder(WoodType.class, "crafting_table",
                        getModBlock("spruce_crafting_table"), () -> VanillaWoodTypes.SPRUCE,
                        w -> new MoreCraftingTableBlock(w.planks.method_26403()))
                //TEXTUREs: oak_craftng_table as BaseTexture
                .addTextureM(EveryCompat.res("block/spruce_crafting_table_front"), EveryCompat.res("block/lolmct/spruce_crafting_table_front_m"))
                .addTextureM(EveryCompat.res("block/spruce_crafting_table_side"), EveryCompat.res("block/lolmct/spruce_crafting_table_side_m"))
                .addTextureM(EveryCompat.res("block/spruce_crafting_table_top"), EveryCompat.res("block/lolmct/spruce_crafting_table_top_m"))
                .addTag(class_3481.field_33713, class_7924.field_41254)
                .addTag(TagUtility.fabricTag("workbench"), class_7924.field_41254, class_7924.field_41197)
                .addTag(class_2960.method_60654("lieonstudio:crafting_tables"), class_7924.field_41254, class_7924.field_41197)
                .addTag(class_2960.method_60654("quad:fuel/wood"), class_7924.field_41197)
                .setTabKey(tab)
                .defaultRecipe()
                .build();
        this.addEntry(craftingTable);
    }
}
